HtmlTextDialog class

Inheritance

Constructors

HtmlTextDialog({Key? key, required String title, required UpdatedHtml updatedHtml, required String initialValue, required AppModel app, required String ownerId, required bool isWeb, List<Widget>? extraIcons, required MediaAction? mediaAction})

Properties

app → AppModel
final
extraIcons → List<Widget>?
final
hashCode → int
The hash code for this object.
no setterinherited
initialValue → String
final
isWeb → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mediaAction → MediaAction?
final
ownerId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
updatedHtml → UpdatedHtml
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<HtmlTextDialog>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

height(BuildContext context) → double
open(BuildContext context, AppModel app, String ownerId, String title, UpdatedHtml updatedHtml, String initialValue, bool isWeb, {List<Widget>? extraIcons, required MediaAction? mediaAction}) → void
width(BuildContext context) → double